@@ -31,7 +31,8 @@ t0 <- trajectory() %>%
   timeout(1) %>%
   rollback(2)
 
-plot(t0)
+## ---- eval=FALSE---------------------------------------------------------
+#  plot(t0)
 
 ## ---- message=FALSE------------------------------------------------------
 cat(plot(t0, output="DOT"))
